# -*- coding: utf-8 -*-

"""Top-level package for Chinese Tokenzier iterator."""
import os

__author__ = """Xiaoquan Kong"""
__email__ = 'u1mail2me@gmail.com'
__version__ = '0.1.1'

ltp_data_base_dir = os.path.join(os.environ.get("HOME"), '.ltp_data')


